@@ -1,4 +1,4 @@
-#!D:\bld\digital_rf_1590951629982\_h_env\python.exe
+#!D:\bld\digital_rf_1591044040594\_h_env\python.exe
 # ----------------------------------------------------------------------------
 # Copyright (c) 2017 Massachusetts Institute of Technology (MIT)
 # All rights reserved.
@@ -246,7 +246,7 @@ class DataPlotter:
 
                 sti_times = np.zeros([self.control.bins], np.complex128)
 
-                for b in np.arange(self.control.bins):
+                for b in np.arange(self.control.bins, dtype=np.int_):
 
                     if self.control.verbose:
                         print(
@@ -319,12 +319,6 @@ class DataPlotter:
 
                 Pss = sti_csd_data_coherence
                 Pss2 = sti_csd_data_phase
-                vmin = np.real(np.median(Pss) - 6.0)
-                vmax = np.real(
-                    np.median(Pss)
-                    + (np.max(Pss) - np.median(Pss)) * 0.61803398875
-                    + 50.0
-                )
                 vmin2 = -np.pi * 1.05
                 vmax2 = np.pi * 1.05
 
@@ -332,12 +326,10 @@ class DataPlotter:
                     vmin = int(self.control.zaxis.split(":")[0])
                     vmax = int(self.control.zaxis.split(":")[1])
                 else:
-                    vmin = np.real(np.median(Pss) - 6.0)
-                    vmax = np.real(
-                        np.median(Pss)
-                        + (np.max(Pss) - np.median(Pss)) * 0.61803398875
-                        + 50.0
-                    )
+                    med_Pss = np.nanmedian(Pss)
+                    max_Pss = np.nanmax(Pss)
+                    vmin = np.real(med_Pss - 6.0)
+                    vmax = np.real(med_Pss + (max_Pss - med_Pss) * 0.61803398875 + 50.0)
 
                 im = ax.imshow(
                     Pss,
@@ -365,7 +357,10 @@ class DataPlotter:
                 # plot dates
 
                 tick_spacing = np.arange(
-                    self.control.bins / 8, self.control.bins, self.control.bins / 8
+                    self.control.bins / 8,
+                    self.control.bins,
+                    self.control.bins / 8,
+                    dtype=np.int_,
                 )
                 ax.set_xticks(tick_spacing)
                 ax1.set_xticks(tick_spacing)
